# Instabot

Forever Free Instagram bot: [promotion and SMM scripts](https://github.com/instagrambot/instabot/tree/master/examples). [API wrapper](https://github.com/instagrambot/instabot/tree/master/instabot/api). [Large community](https://t.me/instabotproject).  

🎉🎉🎉 We are the most used Instagram library on GitHub (according to "Used by" counter). 🎉🎉🎉

---
### [Read the Docs](https://instagrambot.github.io/docs/) | [Contribute](https://github.com/instagrambot/docs/blob/master/CONTRIBUTING.md)
---

[![Telegram Chat](https://img.shields.io/badge/chat%20on-Telegram-blue.svg)](https://t.me/instabotproject)
[![paypal](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://paypal.me/okhlopkov/10)
![Python 2.7, 3.5, 3.6, 3.7](https://img.shields.io/badge/python-2.7%2C%203.5%2C%203.6%2C%203.7-blue.svg)
[![PyPI version](https://badge.fury.io/py/instabot.svg)](https://badge.fury.io/py/instabot)
[![Build Status](https://travis-ci.org/instagrambot/instabot.svg?branch=master)](https://travis-ci.org/instagrambot/instabot)
[![codecov](https://codecov.io/gh/instagrambot/instabot/branch/master/graph/badge.svg)](https://codecov.io/gh/instagrambot/instabot)


### Installation
Install `instabot` with:
``` bash
pip install -U instabot
```
#### or see [this](https://instagrambot.github.io/docs/en/#installation) for more details.



![Instabot is better than other open-source bots!](https://raw.githubusercontent.com/instagrambot/docs/master/img/instabot_3_bots.png "Instabot is better than other open-source bots!")

If this library solved some of your problems, please consider buying [me](https://github.com/ohld) a coffee, sending some bucks to [PayPal](https://paypal.me/okhlopkov/10) or become our [patron](https://patreon.com/join/morejust). :wink:

<a href="https://www.buymeacoffee.com/okhlopkov" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>
